package
Version:
v0.0.0-...-d12a4ab
Opens a new window with list of versions in this module.
Published: Jun 18, 2022
License: LGPL-2.1
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DatabaseQueryRequest struct {
Operation string
SQL string
Parameters [][]interface{}
}
type DatabaseQueryResult struct {
Results []struct {
ColumnName []string
Rows [][]interface{}
}
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.